---
title: SONY PlayStation Portable
language: en
layout: default
created: 2010-01-08 08:47:41 +0100
updated: 2010-01-11 21:39:20 +0100
toc: false
tags:
  - know-how
  - hacking
  - hardware
  - sony
  - playstation
  - psp
---
* **Model:** PSP Slim (PSP-2004)
* **Battery:** PSP-S110

<p><div class="noteclassic" markdown="1">
Please note that these things only work for PSP-1xxx and PSP-2xxx with a date code (found behind battery!) of `8B` or
less. If you have a newer PSP or a PSP-3xxx, you will most likely have a **TA-88v3** mainboard and destroy it by trying
the things described here.
</div></p>


PSP-S110 Pandora Battery
========================

* <http://board.gulli.com/thread/865045-pandora-pandora-batterie-ohne-hombrew-psp-erstellen/12/>

The original shipped battery of type `PSP-S110` can be made a Pandora-battery which enables developer features on the PSP.


Opening the battery
-------------------

![]({{ site.url }}/assets/battery_normal.jpg)

The housing of the battery is glued together around the side. **DO NOT TRY TO OPEN IT WITH A SCREWDRIVER** as you can
easily produce shorts which may even make the battery explode or destroy it forever.

The best way is to use your fingernails and a stronger guitar pick (or something else non-conducting material).

After opening, it will look like this:

![]({{ site.url }}/assets/battery_opened.jpg)

Now carefully bend over the PCB.

![]({{ site.url }}/assets/battery_pcbbend.jpg)


Identify target
---------------

Identify the small 8-pin IC with the label `S93C56` near the **`IC04`** printed on the PCB - this is an EEPROM which
holds information about the battery. We want to stop it sending that information to the PSP.

Looking at a [data sheet](http://www.alldatasheet.com/view.jsp?sSearchword=S93C56), we will find this picture:

![]({{ site.url }}/assets/s93c56scheme.png)

Now there are 2 ways to interfere: We can disconnect the `CS` pin which indicates when a new command is about to be
sent to the IC or we can short the `DO` (data output) pin to `Vcc` so that there will be no readable output from the IC.

If you regularly need a Pandora battery, you can even solder a switch instead of cutting/shorting the points.

### Disconnect CS

* <http://www.psp-forum.com/tutorials-guides/10453-tutorial-make-pandora-battery-stick-no-cfw-psp.html>

The CS line is used to tell the EEPROM when it has to listen for commands. By cutting this line, the EEPROM won't be
able to work anymore and thus you will have a Pandora battery. If you do it right, then you can undo the cut with a
normal pencil (the lead in the pencil is conductive).

Find the line with the **`19`** printed nearby. It is the one going from the top right pin of the IC. Use a razor knife
to cut it at this point (marked red):

![]({{ site.url }}/assets/battery_cutplace.jpg)

That was it! Just assemble everything back and use some adhesive tape to hold the battery together. If you put it into
your PSP (with AC adaptor unplugged), the green *Power*-LED should automatically turn on without doing anything else.

Congratulations. You now have a Pandora battery.

<p><div class="notetip">
If you want to make it a normal battery later, use a lead pencil and draw along the cut a few times. Check that the PSP
doesn't turn on when inserting the battery. If everything works as you want, you can also glue the battery together again.
</div></p>


### Short DO and VCC

* <http://www.psp-hacks.com/2007/10/22/one-wire-pandora-battery-no-software-required/>


Magic MemoryStick
=================

A *Magic MemoryStick* contains a special boot-code which provides means to update the firmware of the PSP. There are
different tools to create one:

* [Ultimate Pandora Magic Stick](http://www.psp-hacks.com/file/1326)
* [TotalNewbi Installer](http://www.megaupload.com/?d=gvzi5ne4)
* [PSPGrader v008](http://pspslimhacks.com/psp-grader-v008/)
* [Rain's UltraLite MMS Maker](http://pspslimhacks.com/rains-ultralite-mms-maker-for-500-m33-4/)

These are all mostly self-explanatory.

After some playing around with my 120MB *MemoryStick Duo* without luck, I came to the conclusion, that you **really need
a *Pro Duo*** for this thing to work. The limit for sticks up to 2GB is gone. You can use any stick - mine was a *8GB
MemoryStick Pro Duo Mark 2*. Be sure to backup all files first.

Using *PSPGrader* and *Rain's UltraLite MMS Maker* didn't work in the first place (tried both with the *Format
MemoryStick* option). The latter one gave the *["IPL failed to inject"](http://www.psp-hacks.com/forums/archive/index.php/t-232186.html)*
error. I then used the `mspformat.exe` from the *TotalNewbi Installer* to format the USB stick. After that, using
*Rain's* (without the *Format* option checked) finally worked and I had a *Magic MemoryStick*.


Using the Magic MemoryStick
---------------------------

To make the PSP load the custom file from the MemoryStick, you have two options:

1. without the MemoryStick in the slot and without AC adapter plugged, put the Pandora battery into
1. the green *Power*-LED should turn on, anything other stays off
1. hold the <kbd>L</kbd> shoulder button while inserting the MMS
1. now the *WIFI*- and *M*-LEDs should flicker and boot the file

you can also do it the other way around:

1. without AC adapter plugged and without battery inserted, put the MMS into the slot
1. hold the <kbd>L</kbd> shoulder button while inserting the Pandora battery
1. the green *Power*-LED should turn on and the *WLAN*- and *M*-LEDs should start to flicker

If only the green *Power*-LED comes on with none of the other LEDs flickering, your Magic MemoryStick mostly doesn't
work. In some rare cases you might have a PSP with the newer mainboard (TA-88v3). Find out [here](http://www.dcemu.co.uk/vbulletin/showthread.php?t=183671).
You might also try [this](http://www.qj.net/psp/homebrew-applications/dark-alex-releases-ta-088v3-identifier-find-out-if-your-psp-is-unhackable.html).


Flashing custom firmware
========================

* <http://forums.gametrailers.com/thread/the-official-psp-custom-firmwa/785993?page=31>
* <http://www.pspmod.com/forums/psp-software-guides/45253-how-install-psp-custom-firmware.html>
* [Team GEN Forums](http://www.pspgen.com/forums/) (mostly French, but one is English)
* [List of all CFWs incl. some background info](http://alek.dark-alex.org/pspwiki/index.php/Custom_Firmwares)

After using the MMS and selecting the first option *Flash install 5.00M33-4*, you will have *Dark Alex*'s firmware on
your PSP. Upgrade it to the latest version by following the steps [here](http://www.atmaxplorer.com/2008/10/psp-custom-firmware-500-m33-is-released/2/).
Just download the *5.00 M33-5*, install it as described there then do the same with the *5.00 M33-6*.

Now you have the choice of switching over to *Team GEN*'s firmware which should support all the latest games. To do
this, use the *XGen Updater* as described [here](http://www.atmaxplorer.com/2009/12/install-psp-custom-firmware-5-50-gen-d3/).
The firmware file is also available [here](http://www.psp-hacks.com/file/1873). Newer versions can then be found in the
Downloads section of [psp-hacks.com](http://www.psp-hacks.com/category/39).

<p><div class="noteimportant" markdown="1">
**ATTENTION!** If you have problems with corrupted savegames or UMD titles not starting, please use the [5.50GEN-D2 Quick Updater](http://dl.qj.net/psp/homebrew-applications/cfw-550gen-d2-quick-updater.html)
to downgrade to that version until 5.50GEN-D4 is out. You might also try [these steps](http://www.pspgen.com/forums/interesting-tidbit-for-those-haveing-trouble-t192838.html)
before doing the downgrade.

If you don't have a backup of your saves, try [this](http://www.maxconsole.net/forums/showpost.php?s=a3670fea1205db04755ba1c6f42f65aa&p=1122026&postcount=3)
to possibly recover them.
</div></p>


Backup your games
=================

* <http://forums.exophase.com/showthread.php?t=4440>
* <http://www.stylemo.com/2007/11/06/how-to-create-iso-backups-of-your-psp-games/>

After you made a backup, copy the resulting `ISO` file into a folder `ISO` on your PSP's MemoryStick. It will then
appear in the game menu under *MemoryStick*.


Homebrew Apps
=============

* [CWCheat System](http://cwcheat.consoleworld.org/index.php)


Links
=====

* <http://forums.afterdawn.com/thread_view.cfm/591203>
* <http://www.pspmod.com/forums/psp-hardware-guides/28603-guide-using-pandoras-battery-easy-way-but-you-must-have-cfw.html>
